@@ -49,4 +49,15 @@ swimming <- endpoint("swimming")
 #' @examples \dontrun{
 #' speed("Oreochromis niloticus")
 #' }
-speed <- endpoint("speed")
\ No newline at end of file
+speed <- endpoint("speed")
+
+#' genetics
+#' 
+#' @return a table of species genetics data
+#' @inheritParams species
+#' @export
+#' @examples \dontrun{
+#' genetics("Oreochromis niloticus")
+#' genetics("Labroides dimidiatus")
+#' }
+genetics <- endpoint("genetics")
